@@ -6,7 +6,7 @@ package WWW::Mechanize;
 use strict;
 use warnings;
 
-our $VERSION = '1.88';
+our $VERSION = '1.89';
 
 use Tie::RefHash;
 use HTTP::Request 1.30;
@@ -32,13 +32,15 @@ sub new {
     );
 
     my %mech_parms = (
-        autocheck   => ($class eq 'WWW::Mechanize' ? 1 : 0),
-        onwarn      => \&WWW::Mechanize::_warn,
-        onerror     => \&WWW::Mechanize::_die,
-        quiet       => 0,
-        stack_depth => 8675309,     # Arbitrarily humongous stack
-        headers     => {},
-        noproxy     => 0,
+        autocheck     => ($class eq 'WWW::Mechanize' ? 1 : 0),
+        onwarn        => \&WWW::Mechanize::_warn,
+        onerror       => \&WWW::Mechanize::_die,
+        quiet         => 0,
+        stack_depth   => 8675309,     # Arbitrarily humongous stack
+        headers       => {},
+        noproxy       => 0,
+        strict_forms  => 0,           # pass-through to HTML::Form
+        verbose_forms => 0,           # pass-through to HTML::Form
     );
 
     my %passed_parms = @_;
@@ -203,6 +205,15 @@ sub back {
 }
 
 
+sub clear_history {
+    my $self = shift;
+
+    delete $self->{page_stack};
+
+    return 1;
+}
+
+
 sub history_count {
     my $self = shift;
 
@@ -532,7 +543,7 @@ sub find_image {
 
     my $wantall = ( $parms{n} eq 'all' );
 
-    $self->_clean_keys( \%parms, qr/^(n|(alt|url|url_abs|tag)(_regex)?)$/ );
+    $self->_clean_keys( \%parms, qr/^(?:n|(?:alt|url|url_abs|tag|id|class)(?:_regex)?)$/ );
 
     my @images = $self->images or return;
 
@@ -575,6 +586,10 @@ sub _match_any_image_parms {
     return if defined $p->{alt_regex}     && !(defined($image->alt) && $image->alt =~ $p->{alt_regex} );
     return if defined $p->{tag}           && !($image->tag && $image->tag eq $p->{tag} );
     return if defined $p->{tag_regex}     && !($image->tag && $image->tag =~ $p->{tag_regex} );
+    return if defined $p->{id}            && !($image->attrs && $image->attrs->{id} && $image->attrs->{id} eq $p->{id} );
+    return if defined $p->{id_regex}      && !($image->attrs && $image->attrs->{id} && $image->attrs->{id} =~ $p->{id_regex} );
+    return if defined $p->{class}         && !($image->attrs && $image->attrs->{class} && $image->attrs->{class} eq $p->{class} );
+    return if defined $p->{class_regex}   && !($image->attrs && $image->attrs->{class} && $image->attrs->{class} =~ $p->{class_regex} );
 
     # Success: everything that was defined passed.
     return 1;
@@ -1519,6 +1534,7 @@ sub _image_from_token {
             height  => $attrs->{height},
             width   => $attrs->{width},
             alt     => $attrs->{alt},
+            attrs   => $attrs,
         });
 }
 
@@ -1584,7 +1600,12 @@ sub _link_from_token {
 sub _extract_forms {
     my $self = shift;
 
-    my @forms = HTML::Form->parse( $self->content, $self->base );
+    my @forms = HTML::Form->parse(
+        $self->content,
+        base    => $self->base,
+        strict  => $self->{strict_forms},
+        verbose => $self->{verbose_forms},
+    );
     $self->{forms} = \@forms;
     for my $form ( @forms ) {
         for my $input ($form->inputs) {
@@ -1663,7 +1684,7 @@ WWW::Mechanize - Handy web browsing in a Perl object
 
 =head1 VERSION
 
-version 1.88
+version 1.89
 
 =head1 SYNOPSIS
 
@@ -1697,6 +1718,21 @@ be queried and revisited.
         button    => 'Search Now'
     );
 
+    # Enable strict form processing to catch typos and non-existant form fields.
+    my $strict_mech = WWW::Mechanize->new( strict_forms => 1);
+
+    $strict_mech->get( $url );
+
+    # This method call will die, saving you lots of time looking for the bug.
+    $strict_mech->submit_form(
+        form_number => 3,
+        fields      => {
+            usernaem     => 'mungo',           # typo in field name
+            password     => 'lost-and-alone',
+            extra_field  => 123,               # field does not exist
+        }
+    );
+
 =head1 DESCRIPTION
 
 C<WWW::Mechanize>, or Mech for short, is a Perl module for stateful
@@ -1865,6 +1901,30 @@ history.
 
 =back
 
+In addition, WWW::Mechanize also allows you to globally enable
+strict and verbose mode for form handling, which is done with L<HTML::Form>.
+
+=over 4
+
+=item * C<< strict_forms => [0|1] >>
+
+Globally sets the HTML::Form strict flag which causes form submission to
+croak if any of the passed fields don't exist in the form, and/or a value
+doesn't exist in a select element. This can still be disabled in individual
+calls to C<L<< submit_form()|"$mech->submit_form( ... )" >>>.
+
+Default is off.
+
+=item * C<< verbose_forms => [0|1] >>
+
+Globally sets the HTML::Form verbose flag which causes form submission to
+warn about any bad HTML form constructs found. This cannot be disabled
+later.
+
+Default is off.
+
+=back
+
 To support forms, WWW::Mechanize's constructor pushes POST
 on to the agent's C<requests_redirectable> list (see also
 L<LWP::UserAgent>.)
@@ -1972,6 +2032,10 @@ would it do if it could?)
 
 Returns true if it could go back, or false if not.
 
+=head2 $mech->clear_history()
+
+This deletes all the history entries and returns true.
+
 =head2 $mech->history_count()
 
 This returns the number of items in the browser history.  This number I<does>
@@ -2327,7 +2391,7 @@ key/value pairs:
 
 =over 4
 
-=item * C<< alt => 'string' >> and C<< alt_regex => qr/regex/, >>
+=item * C<< alt => 'string' >> and C<< alt_regex => qr/regex/ >>
 
 C<alt> matches the ALT attribute of the image against I<string>, which must be an
 exact match. To select a image with an ALT tag that is exactly "download", use
@@ -2340,7 +2404,7 @@ anywhere in it, regardless of case, use
 
     $mech->find_image( alt_regex => qr/download/i );
 
-=item * C<< url => 'string', >> and C<< url_regex => qr/regex/, >>
+=item * C<< url => 'string' >> and C<< url_regex => qr/regex/ >>
 
 Matches the URL of the image against I<string> or I<regex>, as appropriate.
 The URL may be a relative URL, like F<foo/bar.html>, depending on how
@@ -2362,6 +2426,45 @@ more than one tag, as in:
 
 The tags supported are C<< <img> >> and C<< <input> >>.
 
+=item * C<< id => string >> and C<< id_regex => regex >>
+
+C<id> matches the id attribute of the image against I<string>, which must
+be an exact match. To select an image with the exact id "download-image", use
+
+    $mech->find_image( id => 'download-image' );
+
+C<id_regex> matches the id attribute of the image against a regular
+expression. To select the first image with an id that contains "download"
+anywhere in it, use
+
+    $mech->find_image( id_regex => qr/download/ );
+
+=item * C<< classs => string >> and C<< class_regex => regex >>
+
+C<class> matches the class attribute of the image against I<string>, which must
+be an exact match. To select an image with the exact class "img-fuid", use
+
+    $mech->find_image( class => 'img-fluid' );
+
+To select an image with the class attribute "rounded float-left", use
+
+    $mech->find_image( class => 'rounded float-left' );
+
+Note that the classes have to be matched as a complete string, in the exact
+order they appear in the website's source code.
+
+C<class_regex> matches the class attribute of the image against a regular
+expression. Use this if you want a partial class name, or if an image has
+several classes, but you only care about one.
+
+To select the first image with the class "rounded", where there are multiple
+images that might also have either class "float-left" or "float-right", use
+
+    $mech->find_image( class_regex => qr/\brounded\b/ );
+
+Selecting an image with multiple classes where you do not care about the
+order they appear in the website's source code is not currently supported.
+
 =back
 
 If C<n> is not specified, it defaults to 1.  Therefore, if you don't
@@ -2725,7 +2828,11 @@ Sets the x or y values for C<L<< click()|"$mech->click( $button [, $x, $y] )" >>
 
 Sets the HTML::Form strict flag which causes form submission to croak if any of the passed
 fields don't exist on the page, and/or a value doesn't exist in a select element.
-By default HTML::Form defaults this value to false.
+By default HTML::Form sets this value to false.
+
+This behavior can also be turned on globally by passing C<< strict_forms => 1>> to
+C<<WWW::Mechanize->new>>. If you do that, you can still disable it for individual calls
+by passing C<< strict_forms => 0>> here.
 
 =back
 
@@ -3059,7 +3166,7 @@ may be overridden by setting C<onerror> in the constructor.
 The default settings can get you up and running quickly, but there are settings
 you can change in order to make your life easier.
 
-=over4
+=over 4
 
 =item autocheck
 
@@ -3107,9 +3214,14 @@ C<file:///etc/passwd>
 
 =item strict_forms
 
-Consider supplying the C<strict_forms> argument as a rule when you are using
-C<submit_form>.  This will perform a helpful sanity check on the form fields
-you are submitting, which can save you a lot of debugging time.
+Consider turning on the C<strict_forms> option when you create a new Mech.
+This will perform a helpful sanity check on form fields every time you are
+submitting a form, which can save you a lot of debugging time.
+
+    my $agent = WWW::Mechanize->new( strict_forms => 1 );
+
+If you do not want to have this option globally, you can still turn it on for
+individual forms.
 
     $agent->submit_form( fields => { foo => 'bar' } , strict_forms => 1 );
 
